########################################################################################################################
# Copyright 2023 the authors (see AUTHORS file for full list).                                                         #
#                                                                                                                      #
# This file is part of shapelets.                                                                                      #
#                                                                                                                      #
# Shapelets is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General       #
# Public License as published by the Free Software Foundation, either version 2.1 of the License, or (at your option)  #
# any later version.                                                                                                   #
#                                                                                                                      #
# Shapelets is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied      #
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more  #
# details.                                                                                                             #
#                                                                                                                      #
# You should have received a copy of the GNU Lesser General Public License along with shapelets. If not, see           #
# <https://www.gnu.org/licenses/>.                                                                                     #
########################################################################################################################

r"""

This submodule contains documentation for several examples (see below), installation instructions, custom commands, library interfacing, and a CHANGELOG for detailed commit history.

Examples for the **shapelets.self_assembly** submodule:
* Example 1 - computing the response distance ([R. Suderman (2015)](https://doi.org/10.1103/PhysRevE.91.033307))
* Example 2 - the defect identification method ([M.P. Tino (2024)](http://dx.doi.org/10.1088/1361-6528/ad1df4))
* Example 3 - local pattern orientation method ([M.P. Tino (2024)](http://dx.doi.org/10.1088/1361-6528/ad1df4))

Examples for the **shapelets.astronomy** submodule:
* Example 4 - decomposition and reconstruction of images of galaxies ([A. Refregier (2003)](https://doi.org/10.1046/j.1365-8711.2003.05901.x))

"""

from .example_1 import *
from .example_2 import *
from .example_3 import *
from .example_4 import *
from .installation_guide import *
from .library_interface import *
from .custom_commands import *